#define BUILD_NUMBER \
	"build-24276846"
#define BUILD_NUMBER_NUMERIC \
	24276846
#define BUILD_NUMBER_NUMERIC_STRING \
	"24276846"
#define PRODUCT_BUILD_NUMBER \
	"product-build-51152"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	51152
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"51152"
