/*********************************************************
 * Copyright (C) 2013,2018-2019 VMware, Inc. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation version 2.1 and no later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *********************************************************/

/*
 * vmhgfs_version.h --
 *
 * Version definitions for the Linux vmhgfs driver.
 */

#ifndef _VMHGFS_VERSION_H_
#define _VMHGFS_VERSION_H_

#define VMHGFS_DRIVER_VERSION          1.6.12.0
#define VMHGFS_DRIVER_VERSION_COMMAS   1,6,12,0
#define VMHGFS_DRIVER_VERSION_STRING   "1.6.12.0"

#endif /* _VMHGFS_VERSION_H_ */
